pub struct IndicatorConstraintHandle<'a> { /* private fields */ }Expand description
Model-bound handle returned by a scalar indicator declaration.
Implementations
Sourceimpl IndicatorConstraintHandle<'_>
impl IndicatorConstraintHandle<'_>
Sourceimpl IndicatorConstraintHandle<'_>
impl IndicatorConstraintHandle<'_>
Sourcepub fn to_reformulated_model(
self,
options: IndicatorReformulationOptions,
) -> Result<ReformulatedModel, ReformulationError>
pub fn to_reformulated_model( self, options: IndicatorReformulationOptions, ) -> Result<ReformulatedModel, ReformulationError>
Clone the model and replace this active indicator with Big-M rows.
Errors
Returns a reformulation error if the body, bounds, or options are invalid.
Sourcepub fn reformulate(
self,
options: IndicatorReformulationOptions,
) -> Result<Option<IndicatorReformulationArtifacts>, ReformulationError>
pub fn reformulate( self, options: IndicatorReformulationOptions, ) -> Result<Option<IndicatorReformulationArtifacts>, ReformulationError>
Replace this indicator in place. Returns None when it is already inactive.
Errors
Returns an error before mutation if the selected indicator is invalid.