variable!() { /* proc-macro */ }Expand description
variable!(model, spec), declare a decision variable (or an indexed family)
and bind it to a local of the same name. See the crate docs for the grammar.
variable!() { /* proc-macro */ }variable!(model, spec), declare a decision variable (or an indexed family)
and bind it to a local of the same name. See the crate docs for the grammar.