pub struct IndexedVarBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> IndexedVarBuilder<'a>
impl<'a> IndexedVarBuilder<'a>
pub fn lb(self, v: f64) -> Self
pub fn ub(self, v: f64) -> Self
pub fn bounds(self, lb: f64, ub: f64) -> Self
Sourcepub fn lb_by<K, F>(self, f: F) -> Self
pub fn lb_by<K, F>(self, f: F) -> Self
Per-key lower bound. Overrides Self::lb when both are set.
The closure receives a typed index value via FromIndexKey.
Annotate the argument to select the projection:
ⓘ
.lb_by(|(p, q): (String, String)| floor_for(&p, &q))
.lb_by(|i: usize| lower_bounds[i])Sourcepub fn ub_by<K, F>(self, f: F) -> Self
pub fn ub_by<K, F>(self, f: F) -> Self
Per-key upper bound. Overrides Self::ub when both are set.
The closure receives a typed index value via FromIndexKey; annotate
the argument to select the projection:
ⓘ
.ub_by(|(p, q): (String, String)| capacity_for(&p, &q))
.ub_by(|i: usize| upper_bounds[i])pub fn domain(self, d: Domain) -> Self
pub fn integer(self) -> Self
pub fn binary(self) -> Self
pub fn build(self) -> IndexedVar<'a>