param!() { /* proc-macro */ }Expand description
param!(model, name = value), declare a re-bindable scalar parameter and
bind it to a local of the same name.
param!() { /* proc-macro */ }param!(model, name = value), declare a re-bindable scalar parameter and
bind it to a local of the same name.